Class: DocuSign_Monitor::DataSetApi
- Inherits:
-
Object
- Object
- DocuSign_Monitor::DataSetApi
- Defined in:
- lib/docusign_monitor/api/data_set_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_stream(data_set_name, version, options = DocuSign_Monitor::GetStreamOptions.default) ⇒ CursoredResult
Allows for the streaming of data as it becomes available Required scopes: impersonation.
-
#get_stream_with_http_info(data_set_name, version, options = DocuSign_Monitor::GetStreamOptions.default) ⇒ Array<(CursoredResult, Fixnum, Hash)>
Allows for the streaming of data as it becomes available Required scopes: impersonation.
-
#initialize(api_client = DataSetApi.default) ⇒ DataSetApi
constructor
A new instance of DataSetApi.
-
#post_web_query(data_set_name, version, web_query) ⇒ AggregateResult
Allows for querying existing data using filter and aggregation clauses Required scopes: impersonation.
-
#post_web_query_with_http_info(data_set_name, version, web_query) ⇒ Array<(AggregateResult, Fixnum, Hash)>
Allows for querying existing data using filter and aggregation clauses Required scopes: impersonation.
Constructor Details
#initialize(api_client = DataSetApi.default) ⇒ DataSetApi
Returns a new instance of DataSetApi.
32 33 34 |
# File 'lib/docusign_monitor/api/data_set_api.rb', line 32 def initialize(api_client = DataSetApi.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
30 31 32 |
# File 'lib/docusign_monitor/api/data_set_api.rb', line 30 def api_client @api_client end |
Instance Method Details
#get_stream(data_set_name, version, options = DocuSign_Monitor::GetStreamOptions.default) ⇒ CursoredResult
Allows for the streaming of data as it becomes available Required scopes: impersonation
42 43 44 45 |
# File 'lib/docusign_monitor/api/data_set_api.rb', line 42 def get_stream(data_set_name, version, = DocuSign_Monitor::GetStreamOptions.default) data, _status_code, _headers = get_stream_with_http_info(data_set_name, version, ) return data end |
#get_stream_with_http_info(data_set_name, version, options = DocuSign_Monitor::GetStreamOptions.default) ⇒ Array<(CursoredResult, Fixnum, Hash)>
Allows for the streaming of data as it becomes available Required scopes: impersonation
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/docusign_monitor/api/data_set_api.rb', line 53 def get_stream_with_http_info(data_set_name, version, = DocuSign_Monitor::GetStreamOptions.default) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: DataSetApi.get_stream ..." end # verify the required parameter 'data_set_name' is set fail ArgumentError, "Missing the required parameter 'data_set_name' when calling DataSetApi.get_stream" if data_set_name.nil? # verify the required parameter 'version' is set fail ArgumentError, "Missing the required parameter 'version' when calling DataSetApi.get_stream" if version.nil? # resource path local_var_path = "/api/v{version}/datasets/{dataSetName}/stream".sub('{format}','json').sub('{' + 'dataSetName' + '}', data_set_name.to_s).sub('{' + 'version' + '}', version.to_s) # query parameters query_params = {} query_params[:'cursor'] = .cursor if !.cursor.nil? query_params[:'limit'] = .limit if !.limit.nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'CursoredResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: DataSetApi#get_stream\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_web_query(data_set_name, version, web_query) ⇒ AggregateResult
Allows for querying existing data using filter and aggregation clauses Required scopes: impersonation
101 102 103 104 |
# File 'lib/docusign_monitor/api/data_set_api.rb', line 101 def post_web_query(data_set_name, version, web_query) data, _status_code, _headers = post_web_query_with_http_info(data_set_name, version, web_query) return data end |
#post_web_query_with_http_info(data_set_name, version, web_query) ⇒ Array<(AggregateResult, Fixnum, Hash)>
Allows for querying existing data using filter and aggregation clauses Required scopes: impersonation
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/docusign_monitor/api/data_set_api.rb', line 112 def post_web_query_with_http_info(data_set_name, version, web_query) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: DataSetApi.post_web_query ..." end # verify the required parameter 'data_set_name' is set fail ArgumentError, "Missing the required parameter 'data_set_name' when calling DataSetApi.post_web_query" if data_set_name.nil? # verify the required parameter 'version' is set fail ArgumentError, "Missing the required parameter 'version' when calling DataSetApi.post_web_query" if version.nil? # verify the required parameter 'web_query' is set fail ArgumentError, "Missing the required parameter 'web_query' when calling DataSetApi.post_web_query" if web_query.nil? # resource path local_var_path = "/api/v{version}/datasets/{dataSetName}/web_query".sub('{format}','json').sub('{' + 'dataSetName' + '}', data_set_name.to_s).sub('{' + 'version' + '}', version.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(web_query) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'AggregateResult') if @api_client.config.debugging @api_client.config.logger.debug "API called: DataSetApi#post_web_query\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |